@@ -8,7 +8,7 @@ logger = logging.getLogger()
 logging.getLogger('calcbench').setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler(stream=sys.stdout))
 """
-__version__ = "5.5.1"
+__version__ = "5.6.0"
 from .api_client import (
     as_reported_raw,
     business_combinations,
@@ -34,7 +34,7 @@ from .disclosures import disclosure_dataframe as document_dataframe
 
 from .companies import tickers, companies, companies_raw
 from .listener import handle_filings
-from .filing import filings, Filing
+from .filing import filings, Filing, filings_dataframe
 from .metrics import available_metrics, available_metrics_dataframe
 from .standardized_numeric import (
     normalized_data,
